var app = {
  initialize: function() {
    this.bindEvents();
  },
  bindEvents: function() {
    document.addEventListener('deviceready', this.onDeviceReady, false);
  },
  onDeviceReady: function() {
    app.receivedEvent('deviceready');
  },
  receivedEvent: function(id) {
    initDom();
  }
};

/*
 * Global variables
 */
var host = "fcpersepolisrest.ehsun7b.cloudbees.net"; //"perspolis-news.appspot.com";
var linkToMarket = "market://details?id=com.ehsunbehravesh.fcpersepolis"; //"https://play.google.com/store/apps/details?id=com.ehsunbehravesh.fcpersepolis";
var newsList = null;
var arteshNewsList = null;
var persepolisNewsList = null;
var varzesh3NewsList = null;
var currentNews = null;
var ranking = null;
var matchinfo = null;
var uuid = null;
var db = null;
var rateStatus = 0; // 0 not rated - 1 rated - 2 never ask
var timerConnectionTest;
var timerConnectionResult;
var connectionResult = 0;


function initDom() {
  getUuid();
  initEventHandlers();
  homePageInit();
  initDatabase();
  setTimerForRate();
  setTimerForConnectionTest();
}

function initDatabase() {
  db = window.openDatabase("FCP_Database", "1.0", "Database", 2 * 1024 * 1024);

  db.transaction(
          function query(tx) {
            var sql = "CREATE TABLE IF NOT EXISTS SETTINGS (id INTEGER PRIMARY KEY AUTOINCREMENT, key TEXT, value TEXT)";
            tx.executeSql(sql);

            sql = "SELECT * FROM SETTINGS WHERE KEY = ?";
            tx.executeSql(sql, ["RATE_STATUS"], function(tx, result) {
              if (result.rows.length > 0) {
                rateStatus = parseInt(result.rows.item(0).value);
              } else {
                sql = "INSERT INTO SETTINGS (KEY, VALUE) VALUES ('RATE_STATUS', 0)";
                tx.executeSql(sql);
              }
            }, function() {
              console.log("Execute query error!");
            });
          },
          function() {
            console.log("Database transaction error!");
          }
  );
}

function getUuid() {
  try {
    if (device.uuid !== undefined) {
      uuid = device.uuid;
    }
  } catch (e) {
    //alert(e);
    console.log(e);
  }
}

function initEventHandlers() {
  initPages();

  $(".btnExit").click(function() {
    exitApp();
  });

  $("#btnRefresh").click(function() {
    loadNews();
  });

  $("#btnArteshRefresh").click(function() {
    loadArteshNews();
  });

  $("#btnPersepolisRefresh").click(function() {
    loadPersepolisNews();
  });

  $("#btnVarzesh3Refresh").click(function() {
    loadVarzesh3News();
  });

  $("#btnRefreshRanking").click(function() {
    loadRanking();
  });

  $("#btnNewsLike").click(function() {
    newsLike();
  });

  $("#btnRefreshMatchinfo").click(function() {
    loadMatchinfo();
  });

  $(window).on("orientationchange", function() {
    var activePage = $.mobile.activePage[0].id;
    if (activePage === "ranking") {
      setTimeout(showRanking, 100);
    }
  });

  $("#btnRateYes").click(function() {
    rateYes();
  });

  $("#btnRateNotNow").click(function() {
    rateNotNow();
  });

  $("#btnRateNever").click(function() {
    rateNever();
  });

  $("#btnNewsText").click(function() {
    showNewsText();
  });

}

function initPages() {
  $(document).on("pageinit", "#news", function(event) {
    newsPageInit();
  });

  $(document).on("pageinit", "#arteshNews", function(event) {
    arteshNewsPageInit();
  });

  $(document).on("pageinit", "#varzesh3News", function(event) {
    varzesh3NewsPageInit();
  });

  $(document).on("pageinit", "#persepolisNews", function(event) {
    persepolisNewsPageInit();
  });

  $(document).on("pageinit", "#show_news", function(event) {
    showNewsPageInit();
  });

  $(document).on("pageinit", "#ranking", function(event) {
    rankingPageInit();
  });

  $(document).on("pageinit", "#matchinfo", function(event) {
    matchinfoPageInit();
  });
}

function homePageInit() {
  try {
    var src = "img/";
    var rndNumber = getRandomInt(1, 19);
    //console.log(rndNumber);
    $("#headerImage").attr("src", src + rndNumber + ".png");
    $("#headerImage").load(function() {
      var interval = setInterval(function() {
        var opacity = parseFloat($("#headerImage").css("opacity"));
        if (opacity < 1) {
          $("#headerImage").css("opacity", opacity + 0.1);
        } else {
          clearInterval(interval)
        }
      }, 100);
    });

  } catch (e) {
    console.log(e);
  }
}

function getRandomInt(min, max) {
  return Math.floor(Math.random() * (max - min + 1)) + min;
}

function newsPageInit() {
  if (newsList === null) {
    loadNews();
  }
}

function arteshNewsPageInit() {
  if (arteshNewsList === null) {
    loadArteshNews();
  }
}

function varzesh3NewsPageInit() {
  if (varzesh3NewsList === null) {
    loadVarzesh3News();
  }
}

function persepolisNewsPageInit() {
  if (persepolisNewsList === null) {
    loadPersepolisNews();
  }
}

function rankingPageInit() {
  if (ranking === null) {
    loadRanking();
  }
}

function matchinfoPageInit() {
  if (matchinfo === null) {
    loadMatchinfo();
  }
}

function showNewsPageInit() {
  if (currentNews !== null) {
    $("#newsTitle").html("");
    $("#newsDescription").html("");
    $("#newsTitle").append(currentNews.title);
    $("#newsDescription").append(currentNews.description);

    //uuid = "3456web";
    if (uuid !== null && uuid !== undefined) {
      try {
        $.ajax({
          type: 'GET',
          url: "http://" + host + "/countlikenews",
          contentType: "application/json",
          dataType: 'jsonp',
          jsonp: 'callback',
          crossDomain: true,
          data: {
            "uuid": uuid,
            "newsUrl": currentNews.link
          },
          success: function(data, status, jqXHR) {
            updateNewsLikeButton(!data.check, data.count);
          },
          error: function(jqXHR, status, error) {
            console.log("Error! : " + status + " - " + error + " - " + jqXHR.status);
          }
        }).done(function() {

        });
      } catch (e) {
        console.log("Error: " + e);
      }
    }
  }
}

function loadNews() {
  $.support.cors = true;
  $.mobile.allowCrossDomainPages = true;

  try {
    $.ajax({
      type: 'GET',
      url: "http://" + host + "/rest/news/jsonp",
      contentType: "application/json",
      dataType: 'jsonp',
      jsonp: 'callback',
      crossDomain: true,
      success: function(data, status, jqXHR) {
        newsList = data;
        showNews();
      },
      error: function(jqXHR, status, error) {
        console.log("Error! : " + status + " - " + error + " - " + jqXHR.status);
      },
      beforeSend: function() {
        $("#newsListView").html("");
        $.mobile.showPageLoadingMsg();
      },
      complete: function() {
        $.mobile.hidePageLoadingMsg();
      }
    }).done(function() {

    });
  } catch (e) {
    console.log("Error: " + e);
  }
}

function loadArteshNews() {
  $.support.cors = true;
  $.mobile.allowCrossDomainPages = true;

  try {
    $.ajax({
      type: 'GET',
      url: "http://" + host + "/rest/artesh/jsonp",
      contentType: "application/json",
      dataType: 'jsonp',
      jsonp: 'callback',
      crossDomain: true,
      success: function(data, status, jqXHR) {
        arteshNewsList = data;
        showArteshNews();
      },
      error: function(jqXHR, status, error) {
        console.log("Error! : " + status + " - " + error + " - " + jqXHR.status);
      },
      beforeSend: function() {
        $("#arteshNewsListView").html("");
        $.mobile.showPageLoadingMsg();
      },
      complete: function() {
        $.mobile.hidePageLoadingMsg();
      }
    }).done(function() {

    });
  } catch (e) {
    console.log("Error: " + e);
  }
}

function loadPersepolisNews() {
  $.support.cors = true;
  $.mobile.allowCrossDomainPages = true;

  try {
    $.ajax({
      type: 'GET',
      url: "http://" + host + "/persepolisnews",
      contentType: "application/json",
      dataType: 'jsonp',
      jsonp: 'callback',
      crossDomain: true,
      success: function(data, status, jqXHR) {
        persepolisNewsList = data;
        showPersepolisNews();
      },
      error: function(jqXHR, status, error) {
        console.log("Error! : " + status + " - " + error + " - " + jqXHR.status);
      },
      beforeSend: function() {
        $("#persepolisNewsListView").html("");
        $.mobile.showPageLoadingMsg();
      },
      complete: function() {
        $.mobile.hidePageLoadingMsg();
      }
    }).done(function() {

    });
  } catch (e) {
    console.log("Error: " + e);
  }
}

function loadVarzesh3News() {
  $.support.cors = true;
  $.mobile.allowCrossDomainPages = true;

  try {
    $.ajax({
      type: 'GET',
      url: "http://" + host + "/varzesh3news",
      contentType: "application/json",
      dataType: 'jsonp',
      jsonp: 'callback',
      crossDomain: true,
      success: function(data, status, jqXHR) {
        varzesh3NewsList = data;
        showVarzesh3News();
      },
      error: function(jqXHR, status, error) {
        console.log("Error! : " + status + " - " + error + " - " + jqXHR.status);
      },
      beforeSend: function() {
        $("#varzesh3NewsListView").html("");
        $.mobile.showPageLoadingMsg();
      },
      complete: function() {
        $.mobile.hidePageLoadingMsg();
      }
    }).done(function() {

    });
  } catch (e) {
    console.log("Error: " + e);
  }
}

function loadRanking() {
  $.support.cors = true;
  $.mobile.allowCrossDomainPages = true;

  try {
    $.ajax({
      type: 'GET',
      url: "http://" + host + "/ranking",
      contentType: "application/json",
      dataType: 'jsonp',
      jsonp: 'callback',
      crossDomain: true,
      success: function(data, status, jqXHR) {
        ranking = data.table;
        showRanking();
      },
      error: function(jqXHR, status, error) {
        console.log("Error! : " + status + " - " + error + " - " + jqXHR.status);
      },
      beforeSend: function() {
        $("#rankingListView").html("");
        $.mobile.showPageLoadingMsg();
      },
      complete: function() {
        $.mobile.hidePageLoadingMsg();
      }
    }).done(function() {

    });
  } catch (e) {
    console.log("Error: " + e);
  }
}

function loadMatchinfo() {
  $.support.cors = true;
  $.mobile.allowCrossDomainPages = true;

  try {
    $.ajax({
      type: 'GET',
      url: "http://" + host + "/matchinfo",
      contentType: "application/json",
      dataType: 'jsonp',
      jsonp: 'callback',
      crossDomain: true,
      success: function(data, status, jqXHR) {
        matchinfo = data;
        showMatchinfo();
      },
      error: function(jqXHR, status, error) {
        console.log("Error! : " + status + " - " + error + " - " + jqXHR.status);
      },
      beforeSend: function() {
        $.mobile.showPageLoadingMsg();
      },
      complete: function() {
        $.mobile.hidePageLoadingMsg();
      }
    }).done(function() {

    });
  } catch (e) {
    console.log("Error: " + e);
  }
}

function showNews() {
  var len = newsList.length;
  for (var i = 0; i < len; ++i) {
    var news = newsList[i];
    $("#newsListView").append($("<li/>", {"data-icon": "false", "class": "news", "rel": i}).append($("<a/>", {"href": "#show_news"}).append(news.title)));
  }
  $('#newsListView').listview('refresh', true);
  setEventHandlerForNewsLinks();
}

function showArteshNews() {
  var len = arteshNewsList.length;
  for (var i = 0; i < len; ++i) {
    var news = arteshNewsList[i];
    $("#arteshNewsListView").append($("<li/>", {"data-icon": "false", "class": "arteshNews", "rel": i}).append($("<a/>", {"href": "#show_news"}).append(news.title)));
  }
  $('#arteshNewsListView').listview('refresh', true);
  setEventHandlerForArteshNewsLinks();
}

function showPersepolisNews() {
  var len = persepolisNewsList.length;
  for (var i = 0; i < len; ++i) {
    var news = persepolisNewsList[i];
    $("#persepolisNewsListView").append($("<li/>", {"data-icon": "false", "class": "persepolisNews", "rel": i}).append($("<a/>", {"href": "#show_news"}).append(news.title)));
  }
  $('#persepolisNewsListView').listview('refresh', true);
  setEventHandlerForPersepolisNewsLinks();
}

function showVarzesh3News() {
  var len = varzesh3NewsList.length;
  for (var i = 0; i < len; ++i) {
    var news = varzesh3NewsList[i];
    $("#varzesh3NewsListView").append($("<li/>", {"data-icon": "false", "class": "varzesh3News", "rel": i}).append($("<a/>", {"href": "#show_news"}).append(news.title)));
  }
  $('#varzesh3NewsListView').listview('refresh', true);
  setEventHandlerForVarzesh3NewsLinks();
}

function showRanking() {
  switch (whichRankingType()) {
    case "list":
      showListRanking();
      break;
    case "compact":
      showCompactRanking();
      break;
    case "full":
      showFullRanking();
      break;
  }
}

function whichRankingType() {
  var viewport = {
    width: $(window).width(),
    height: $(window).height()
  };

  if (viewport.width > 565) {
    return "full";
  } else if (viewport.width > 300) {
    return "compact";
  } else {
    return "list";
  }
}

function showFullRanking() {
  $("#rankingContainer").html("");
  var table = $("<table/>", {"id": "tblRanking"});

  var tr = $("<tr/>");
  tr.append($("<th/>").append("ردیف"));
  tr.append($("<th/>").append("تیم"));
  tr.append($("<th/>").append("بازی"));
  tr.append($("<th/>").append("برد"));
  tr.append($("<th/>").append("مساوی"));
  tr.append($("<th/>").append("باخت"));
  tr.append($("<th/>").append("گل زده"));
  tr.append($("<th/>").append("گل خورده"));
  tr.append($("<th/>").append("تفاضل گل"));
  tr.append($("<th/>").append("امتیاز"));

  table.append(tr);

  var len = ranking.length;
  for (var i = 0; i < len; ++i) {
    var node = ranking[i];
    var tr = $("<tr/>");
    tr.attr("class", (i % 2 === 0 ? "even" : "odd"));

    tr.append($("<td/>").append(i + 1));
    tr.append($("<td/>").append(node.team));
    tr.append($("<td/>").append(node.matches));
    tr.append($("<td/>").append(node.wins));
    tr.append($("<td/>").append(node.draws));
    tr.append($("<td/>").append(node.looses));
    tr.append($("<td/>").append(node.scoredGoals));
    tr.append($("<td/>").append(node.receivedGoals));
    tr.append($("<td/>").append(node.differentGoals));
    tr.append($("<td/>").append(node.points));

    table.append(tr);
  }

  $("#rankingContainer").append(table);
}

function showCompactRanking() {
  $("#rankingContainer").html("");
  var table = $("<table/>", {"id": "tblRanking"});

  var tr = $("<tr/>");
  tr.append($("<th/>").append("ردیف"));
  tr.append($("<th/>").append("تیم"));
  tr.append($("<th/>").append("بازی"));
  tr.append($("<th/>").append("امتیاز"));

  table.append(tr);

  var len = ranking.length;
  for (var i = 0; i < len; ++i) {
    var node = ranking[i];
    var tr = $("<tr/>");
    tr.attr("class", (i % 2 === 0 ? "even" : "odd"));

    tr.append($("<td/>").append(i + 1));
    tr.append($("<td/>").append(node.team));
    tr.append($("<td/>").append(node.matches));
    tr.append($("<td/>").append(node.points));

    table.append(tr);
  }

  $("#rankingContainer").append(table);
}

function showListRanking() {
  $("#rankingContainer").html("");

  var len = ranking.length;
  for (var i = 0; i < len; ++i) {
    var node = ranking[i];
    $("#rankingListView").append(($("<li/>", {"data-icon": "false"}).append(" " + node.team + ": " + node.points))
            .append($("<ul/>").append(
                    $("<li/>").append(node.points + " امتیاز"))
                    .append($("<li/>").append(node.matches + " بازی"))
                    .append($("<li/>").append(node.wins + " برد"))
                    .append($("<li/>").append(node.draws + " مساوی"))
                    .append($("<li/>").append(node.looses + " باخت"))
                    .append($("<li/>").append(node.differentGoals + " تفاضل گل"))
                    .append($("<li/>").append(node.scoredGoals + " گل زده"))
                    .append($("<li/>").append(node.receivedGoals + " گل خورده"))
                    )
            );
  }
  $('#rankingListView').listview('refresh', true);
}

function showMatchinfo() {
  var imageUrl = "http://" + host + "/image?url=";
  if (matchinfo !== null) {
    $("td#preHomeTeam").html(matchinfo.preMatch.homeTeam);
    $("td#preGuestTeam").html(matchinfo.preMatch.guestTeam);
    $("td#preHomeScore").html(matchinfo.preMatch.homeTeamScore);
    $("td#preGuestScore").html(matchinfo.preMatch.guestTeamScore);
    $("td#preHomeTeamLogo").html($("<img/>", {"src": imageUrl + matchinfo.preMatch.homeTeamLogo}));
    $("td#preGuestTeamLogo").html($("<img/>", {"src": imageUrl + matchinfo.preMatch.guestTeamLogo}));
    $("td#preDescription").html(matchinfo.preMatch.matchDescription);

    $("td#nextHomeTeam").html(matchinfo.nextMatch.homeTeam);
    $("td#nextGuestTeam").html(matchinfo.nextMatch.guestTeam);
    $("td#nextHomeScore").html(matchinfo.nextMatch.homeTeamScore);
    $("td#nextGuestScore").html(matchinfo.nextMatch.guestTeamScore);
    $("td#nextHomeTeamLogo").html($("<img/>", {"src": imageUrl + matchinfo.nextMatch.homeTeamLogo}));
    $("td#nextGuestTeamLogo").html($("<img/>", {"src": imageUrl + matchinfo.nextMatch.guestTeamLogo}));
    $("td#nextDescription").html(matchinfo.nextMatch.matchDescription);
  }
}

function setEventHandlerForNewsLinks() {
  $("li.news").click(function() {
    var index = parseInt($(this).attr("rel"));
    if (index >= 0) {
      currentNews = newsList[index];
      showNewsPageInit();
    }
  });
}

function setEventHandlerForArteshNewsLinks() {
  $("li.arteshNews").click(function() {
    var index = parseInt($(this).attr("rel"));
    if (index >= 0) {
      currentNews = arteshNewsList[index];
      showNewsPageInit();
    }
  });
}

function setEventHandlerForPersepolisNewsLinks() {
  $("li.persepolisNews").click(function() {
    var index = parseInt($(this).attr("rel"));
    if (index >= 0) {
      currentNews = persepolisNewsList[index];
      showNewsPageInit();
    }
  });
}

function newsLike() {
  //uuid = "3456788web";

  if (uuid !== null && uuid !== undefined) {
    try {
      $.ajax({
        type: 'GET',
        url: "http://" + host + "/likenews",
        data: {
          "uuid": uuid,
          "newsUrl": currentNews.link,
          "newsTitle": currentNews.title,
          /*"newsDescription": currentNews.description*/
        },
        dataType: 'jsonp',
        jsonp: 'callback',
        contentType: "application/json",
        crossDomain: true,
        beforeSend: function() {
          $.mobile.showPageLoadingMsg();
        },
        complete: function() {
          $.mobile.hidePageLoadingMsg();
          updateNewsLikeButton(false, null, 1);
        }
      }).done(function() {

      });
    } catch (e) {
      console.log("Error: " + e);
    }
  }
}

function setTimerForRate() {
  if (rateStatus === 0) {
    var interval = getRandomInt(30, 120);
    setTimeout(askForRate, interval * 1000);
  }
}

function setTimerForConnectionTest() {
  timerConnectionTest = setInterval(connectionTest, 30000);
  setTimeout(function() {
    timerConnectionResult = setInterval(checkConnectionResult, 30000);
  }, 5000);

}

function connectionTest() {
  connectionResult = -1;
  console.log("connection test");
  $.ajax({
    type: 'GET',
    url: "http://" + host + "/connectiontest",
    dataType: 'jsonp',
    jsonp: 'callback',
    contentType: "application/json",
    crossDomain: true,
    success: function(data, status, jqXHR) {
      connectionResult = parseInt(data);
    },
    beforeSend: function() {
      $("#connection").html("Testing connection ...");
    }
  });
}

function checkConnectionResult() {
  console.log("checking connection result.");
  $("#connection").html("");
  //alert(connectionResult);
  if (connectionResult !== 1) {
    if (!internetConnection()) {
      alert("No Connection!");
    } else {
      alert("Server is updating. Please try in 5 minutes.");
    }
  }
}

function internetConnection() {
  var result = false;

  var networkState = navigator.connection.type;

  //states[Connection.UNKNOWN]  = 'Unknown connection';
  //states[Connection.ETHERNET] = 'Ethernet connection';
  //states[Connection.WIFI]     = 'WiFi connection';
  //states[Connection.CELL_2G]  = 'Cell 2G connection';
  //states[Connection.CELL_3G]  = 'Cell 3G connection';
  //states[Connection.CELL_4G]  = 'Cell 4G connection';
  //states[Connection.NONE]     = 'No network connection';

  if (networkState === Connection.ETHERNET) {
    result = true;
  } else if (networkState === Connection.WIFI) {
    result = true;
  } else if (networkState === Connection.CELL_2G) {
    result = true;
  } else if (networkState === Connection.CELL_3G) {
    result = true;
  } else if (networkState === Connection.CELL_4G) {
    result = true;
  }

  return result;
}


function askForRate() {
  if (rateStatus <= 0) {
    $("#btnDlgRate").click();
  }
}

function setEventHandlerForVarzesh3NewsLinks() {
  $("li.varzesh3News").click(function() {
    var index = parseInt($(this).attr("rel"));
    if (index >= 0) {
      currentNews = varzesh3NewsList[index];
      showNewsPageInit();
    }
  });
}

function updateNewsLikeButton(enable, likes, increment) {
  if (likes !== null) {
    $("#btnNewsLike").data("count", likes + 30);
  }

  var intLikes = parseInt($("#btnNewsLike").data("count"));

  if (increment !== undefined) {
    intLikes += increment;
  }

  $("#likes").html(intLikes);
  if (enable) {
    $("#btnNewsLike").removeAttr("disabled");
  } else {
    $("#btnNewsLike").attr("disabled", "disabled");
  }
  $("#btnNewsLike").button("refresh");
}

function rateYes() {
  try {
    window.open(linkToMarket, '_system');
    db.transaction(
            function query(tx) {
              var sql = "UPDATE SETTINGS SET VALUE = ? WHERE KEY = ?";
              tx.executeSql(sql, ["1", "RATE_STATUS"]);
            },
            function() {
              console.log("Database transaction error!");
            }
    );
  } catch (e) {
    console.error(e);
  }
}

function rateNotNow() {
  //console.log("not now");
}

function rateNever() {
  try {
    db.transaction(
            function query(tx) {
              var sql = "UPDATE SETTINGS SET VALUE = ? WHERE KEY = ?";
              tx.executeSql(sql, ["2", "RATE_STATUS"]);
            },
            function() {
              console.log("Database transaction error!");
            }
    );
  } catch (e) {
    console.error(e);
  }
}

function showNewsText() {
  var link = "http://" + host + "/newstext?url=" + currentNews.link + "&title=" + encodeURI(currentNews.title);
  navigator.app.loadUrl(link, {openExternal: true});
  return false;
}

function exitApp() {
  navigator.app.exitApp();
}